@@ -15,13 +15,19 @@
 
 import json
 import mock
-import Queue
 import requests
 import unittest
 
-from monasca_notification.notification import Notification
+import six
+
+from monasca_notification import notification as m_notification
 from monasca_notification.plugins import webhook_notifier
 
+if six.PY2:
+    import Queue as queue
+else:
+    import queue
+
 
 def alarm(metrics):
     return {"tenantId": "0",
@@ -46,7 +52,7 @@ class requestsResponse(object):
 
 class TestWebhook(unittest.TestCase):
     def setUp(self):
-        self.trap = Queue.Queue()
+        self.trap = queue.Queue()
         self.webhook_config = {'timeout': 50}
 
     def tearDown(self):
@@ -86,7 +92,8 @@ class TestWebhook(unittest.TestCase):
 
         alarm_dict = alarm(metric)
 
-        notification = Notification(0, 'webhook', 'webhook notification', 'http://mock:3333/', 0, 0, alarm_dict)
+        notification = m_notification.Notification(0, 'webhook', 'webhook notification',
+                                                   'http://mock:3333/', 0, 0, alarm_dict)
 
         self.trap.put(webhook.send_notification(notification))
 
